# Whist Backend

[![Lint](https://github.com/Danie-1/whist_backend/actions/workflows/lint.yml/badge.svg)](https://github.com/Danie-1/whist_backend/actions/workflows/lint.yml)
[![Tests](https://github.com/Danie-1/whist_backend/actions/workflows/tests.yml/badge.svg)](https://github.com/Danie-1/whist_backend/actions/workflows/tests.yml)
[![Documentation Status](https://readthedocs.org/projects/whist-backend/badge/?version=latest)](https://whist-backend.readthedocs.io/en/latest/?badge=latest)

To install, clone this repository and run
```
pip install .
```
in the cloned repository.

See the `examples` folder for example usage.
